@@ -1,6 +1,7 @@
 from dataclasses import dataclass
 
 from energytt_platform.bus import Message
+from energytt_platform.models.common import DateTimeRange
 from energytt_platform.models.measurements import Measurement
 
 
@@ -18,3 +19,15 @@ class MeasurementRemoved(Message):
     TODO
     """
     id: str
+
+
+@dataclass
+class ImportMeasurements(Message):
+    """
+    TODO
+
+    begin.from_ is INCLUDED.
+    begin.to_ is EXCLUDED.
+    """
+    gsrn: str
+    begin: DateTimeRange
