@@ -20,9 +20,13 @@ class InternalToken(Serializable):
     subject: str
 
     # Scopes granted on subject's data
-    # meteringpoints.read, measurements.read, emissions.read, meteringpoint.onboard
+    # meteringpoints.read, measurements.read, emissions.read, etc
     scope: List[str]
 
     @property
-    def is_expired(self) -> bool:
-        return self.expires < datetime.now(tz=timezone.utc)
+    def is_valid(self) -> bool:
+        """
+        A token is valid only if its issued before now, and expires
+        after now.
+        """
+        return self.issued <= datetime.now(tz=timezone.utc) < self.expires
